@@ -1,94 +1,232 @@
-from .alternator import Alternator
 from .adaptive import Adaptive
+from .adaptor import AdaptorBrief, AdaptorLong
+from .alternator import Alternator
 from .ann import EvolvedANN, EvolvedANN5, EvolvedANNNoise05
 from .apavlov import APavlov2006, APavlov2011
 from .appeaser import Appeaser
 from .averagecopier import AverageCopier, NiceAverageCopier
 from .axelrod_first import (
-    Davis, RevisedDowning, Feld, Grofman, Nydegger, Joss, Shubik, Tullock,
-    UnnamedStrategy, SteinAndRapoport, TidemanAndChieruzzi)
+    Davis,
+    Feld,
+    Grofman,
+    Joss,
+    Nydegger,
+    RevisedDowning,
+    Shubik,
+    SteinAndRapoport,
+    TidemanAndChieruzzi,
+    Tullock,
+    UnnamedStrategy,
+)
 from .axelrod_second import (
-    Champion, Eatherley, Tester, Gladstein, Tranquilizer, MoreGrofman,
-    Kluepfel, Borufsen, Cave, WmAdams, GraaskampKatzen, Weiner, Harrington,
-    MoreTidemanAndChieruzzi, Getzler, Leyvraz, White, Black, RichardHufford,
-    Yamachi, Colbert, Mikkelson)
+    Black,
+    Borufsen,
+    Cave,
+    Champion,
+    Colbert,
+    Eatherley,
+    Getzler,
+    Gladstein,
+    GraaskampKatzen,
+    Harrington,
+    Kluepfel,
+    Leyvraz,
+    Mikkelson,
+    MoreGrofman,
+    MoreTidemanAndChieruzzi,
+    RichardHufford,
+    Rowsam,
+    Tester,
+    Tranquilizer,
+    Weiner,
+    White,
+    WmAdams,
+    Yamachi,
+)
 from .backstabber import BackStabber, DoubleCrosser
 from .better_and_better import BetterAndBetter
 from .bush_mosteller import BushMosteller
 from .calculator import Calculator
 from .cooperator import Cooperator, TrickyCooperator
 from .cycler import (
-    AntiCycler, Cycler, CyclerCCD, CyclerCCCD, CyclerCCCCCD,
-    CyclerDC, CyclerDDC, CyclerCCCDCD)
+    AntiCycler,
+    Cycler,
+    CyclerCCCCCD,
+    CyclerCCCD,
+    CyclerCCCDCD,
+    CyclerCCD,
+    CyclerDC,
+    CyclerDDC,
+)
 from .darwin import Darwin
 from .dbs import DBS
 from .defector import Defector, TrickyDefector
 from .doubler import Doubler
 from .finite_state_machines import (
-    Fortress3, Fortress4, Predator, Pun1, Raider, Ripoff, SolutionB1,
-    SolutionB5, Thumper, FSMPlayer, EvolvedFSM4, EvolvedFSM16,
-    EvolvedFSM16Noise05, TF1, TF2, TF3)
+    TF1,
+    TF2,
+    TF3,
+    EvolvedFSM4,
+    EvolvedFSM16,
+    EvolvedFSM16Noise05,
+    Fortress3,
+    Fortress4,
+    FSMPlayer,
+    Predator,
+    Pun1,
+    Raider,
+    Ripoff,
+    UsuallyCooperates,
+    UsuallyDefects,
+    SolutionB1,
+    SolutionB5,
+    Thumper,
+)
 from .forgiver import Forgiver, ForgivingTitForTat
-from .geller import Geller, GellerCooperator, GellerDefector
 from .gambler import (
-    Gambler, PSOGambler1_1_1, PSOGambler2_2_2, PSOGambler2_2_2_Noise05,
-    PSOGamblerMem1, ZDMem2)
-from .gobymajority import (GoByMajority,
-    GoByMajority10, GoByMajority20, GoByMajority40,
+    Gambler,
+    PSOGambler1_1_1,
+    PSOGambler2_2_2,
+    PSOGambler2_2_2_Noise05,
+    PSOGamblerMem1,
+    ZDMem2,
+)
+from .geller import Geller, GellerCooperator, GellerDefector
+from .gobymajority import (
+    GoByMajority,
     GoByMajority5,
-    HardGoByMajority, HardGoByMajority10, HardGoByMajority20, HardGoByMajority40,
-    HardGoByMajority5)
+    GoByMajority10,
+    GoByMajority20,
+    GoByMajority40,
+    HardGoByMajority,
+    HardGoByMajority5,
+    HardGoByMajority10,
+    HardGoByMajority20,
+    HardGoByMajority40,
+)
 from .gradualkiller import GradualKiller
-from .grudger import (Grudger, ForgetfulGrudger, OppositeGrudger, Aggravater,
-    SoftGrudger, GrudgerAlternator, EasyGo, GeneralSoftGrudger)
+from .grudger import (
+    Aggravater,
+    EasyGo,
+    ForgetfulGrudger,
+    GeneralSoftGrudger,
+    Grudger,
+    GrudgerAlternator,
+    OppositeGrudger,
+    SoftGrudger,
+)
 from .grumpy import Grumpy
 from .handshake import Handshake
-from .hmm import HMMPlayer, EvolvedHMM5
+from .hmm import EvolvedHMM5, HMMPlayer
 from .human import Human
 from .hunter import (
-    DefectorHunter, CooperatorHunter, CycleHunter, AlternatorHunter,
-    MathConstantHunter, RandomHunter, EventualCycleHunter)
+    AlternatorHunter,
+    CooperatorHunter,
+    CycleHunter,
+    DefectorHunter,
+    EventualCycleHunter,
+    MathConstantHunter,
+    RandomHunter,
+)
 from .inverse import Inverse
-from .lookerup import (LookerUp,
-    EvolvedLookerUp1_1_1, EvolvedLookerUp2_2_2,
-    Winner12, Winner21)
+from .lookerup import (
+    EvolvedLookerUp1_1_1,
+    EvolvedLookerUp2_2_2,
+    LookerUp,
+    Winner12,
+    Winner21,
+)
 from .mathematicalconstants import Golden, Pi, e
 from .memoryone import (
-    MemoryOnePlayer, ALLCorALLD, FirmButFair, GTFT, SoftJoss,
-    StochasticCooperator, StochasticWSLS, WinStayLoseShift, WinShiftLoseStay,
-    ReactivePlayer)
-from .memorytwo import MemoryTwoPlayer, AON2, DelayedAON1, MEM2
-from .mindcontrol import MindController, MindWarper, MindBender
-from .mindreader import MindReader, ProtectedMindReader, MirrorMindReader
+    GTFT,
+    ALLCorALLD,
+    FirmButFair,
+    MemoryOnePlayer,
+    ReactivePlayer,
+    SoftJoss,
+    StochasticCooperator,
+    StochasticWSLS,
+    WinShiftLoseStay,
+    WinStayLoseShift,
+)
+from .memorytwo import AON2, MEM2, DelayedAON1, MemoryTwoPlayer
+from .mindcontrol import MindBender, MindController, MindWarper
+from .mindreader import MindReader, MirrorMindReader, ProtectedMindReader
 from .mutual import Desperate, Hopeless, Willing
 from .negation import Negation
-from .oncebitten import OnceBitten, FoolMeOnce, ForgetfulFoolMeOnce, FoolMeForever
-from .prober import (CollectiveStrategy, Prober, Prober2, Prober3, Prober4,
-                     HardProber, NaiveProber, RemorsefulProber)
-from .punisher import Punisher, InversePunisher, LevelPunisher, TrickyLevelPunisher
+from .oncebitten import FoolMeForever, FoolMeOnce, ForgetfulFoolMeOnce, OnceBitten
+from .prober import (
+    CollectiveStrategy,
+    HardProber,
+    NaiveProber,
+    Prober,
+    Prober2,
+    Prober3,
+    Prober4,
+    RemorsefulProber,
+)
+from .punisher import InversePunisher, LevelPunisher, Punisher, TrickyLevelPunisher
 from .qlearner import (
-    RiskyQLearner, ArrogantQLearner, HesitantQLearner, CautiousQLearner)
+    ArrogantQLearner,
+    CautiousQLearner,
+    HesitantQLearner,
+    RiskyQLearner,
+)
 from .rand import Random
-from .resurrection import Resurrection, DoubleResurrection
+from .resurrection import DoubleResurrection, Resurrection
 from .retaliate import (
-    Retaliate, Retaliate2, Retaliate3, LimitedRetaliate, LimitedRetaliate2,
-    LimitedRetaliate3)
-from .sequence_player import SequencePlayer, ThueMorse, ThueMorseInverse
+    LimitedRetaliate,
+    LimitedRetaliate2,
+    LimitedRetaliate3,
+    Retaliate,
+    Retaliate2,
+    Retaliate3,
+)
 from .selfsteem import SelfSteem
+from .sequence_player import SequencePlayer, ThueMorse, ThueMorseInverse
 from .shortmem import ShortMem
 from .stalker import Stalker
 from .titfortat import (
-    TitForTat, TitFor2Tats, TwoTitsForTat, Bully, SneakyTitForTat,
-    SuspiciousTitForTat, AntiTitForTat, HardTitForTat, HardTitFor2Tats,
-    OmegaTFT, Gradual, ContriteTitForTat, AdaptiveTitForTat,
-    SpitefulTitForTat, SlowTitForTwoTats2, Alexei, EugineNier,
-    DynamicTwoTitsForTat, NTitsForMTats, Michaelos, RandomTitForTat)
+    AdaptiveTitForTat,
+    Alexei,
+    AntiTitForTat,
+    Bully,
+    ContriteTitForTat,
+    DynamicTwoTitsForTat,
+    EugineNier,
+    Gradual,
+    HardTitFor2Tats,
+    HardTitForTat,
+    Michaelos,
+    NTitsForMTats,
+    OmegaTFT,
+    RandomTitForTat,
+    SlowTitForTwoTats2,
+    SneakyTitForTat,
+    SpitefulTitForTat,
+    SuspiciousTitForTat,
+    TitFor2Tats,
+    TitForTat,
+    TwoTitsForTat,
+)
 from .verybad import VeryBad
-from .worse_and_worse import (WorseAndWorse, KnowledgeableWorseAndWorse,
-                              WorseAndWorse2, WorseAndWorse3)
+from .worse_and_worse import (
+    KnowledgeableWorseAndWorse,
+    WorseAndWorse,
+    WorseAndWorse2,
+    WorseAndWorse3,
+)
 from .zero_determinant import (
-    ZDExtortion, ZDExtort2, ZDExtort3, ZDExtort2v2, ZDExtort4, ZDGen2, ZDGTFT2,
-    ZDMischief, ZDSet2)
+    ZDGTFT2,
+    ZDExtort2,
+    ZDExtort2v2,
+    ZDExtort3,
+    ZDExtort4,
+    ZDExtortion,
+    ZDGen2,
+    ZDMischief,
+    ZDSet2,
+)
 
 # Note: Meta* strategies are handled in .__init__.py
 
@@ -96,6 +234,8 @@ from .zero_determinant import (
 all_strategies = [
     Adaptive,
     AdaptiveTitForTat,
+    AdaptorBrief,
+    AdaptorLong,
     Aggravater,
     Alexei,
     ALLCorALLD,
@@ -251,6 +391,7 @@ all_strategies = [
     RichardHufford,
     Ripoff,
     RiskyQLearner,
+    Rowsam,
     SelfSteem,
     ShortMem,
     Shubik,
@@ -282,6 +423,8 @@ all_strategies = [
     TrickyLevelPunisher,
     Tullock,
     TwoTitsForTat,
+    UsuallyCooperates,
+    UsuallyDefects,
     VeryBad,
     Weiner,
     White,
