@@ -1,11 +1,10 @@
-import numpy as np
-
-from axelrod.action import Action
-from axelrod.player import Player
-from axelrod.load_data_ import load_weights
-
 from typing import List, Tuple
 
+import numpy as np
+from axelrod.action import Action
+from axelrod.load_data_ import load_weights
+from axelrod.player import Player
+
 C, D = Action.C, Action.D
 nn_weights = load_weights()
 
@@ -55,7 +54,7 @@ def compute_features(player: Player, opponent: Player) -> List[int]:
         opponent_second_c = 0
         opponent_second_d = 0
         my_previous_c = 1 if player.history[-1] == C else 0
-        my_previous_d = 0 if player.history[-1] == D else 0
+        my_previous_d = 1 if player.history[-1] == D else 0
         my_previous2_c = 0
         my_previous2_d = 0
         opponent_previous_c = 1 if opponent.history[-1] == C else 0
@@ -69,7 +68,7 @@ def compute_features(player: Player, opponent: Player) -> List[int]:
         opponent_second_c = 1 if opponent.history[1] == C else 0
         opponent_second_d = 1 if opponent.history[1] == D else 0
         my_previous_c = 1 if player.history[-1] == C else 0
-        my_previous_d = 0 if player.history[-1] == D else 0
+        my_previous_d = 1 if player.history[-1] == D else 0
         my_previous2_c = 1 if player.history[-2] == C else 0
         my_previous2_d = 1 if player.history[-2] == D else 0
         opponent_previous_c = 1 if opponent.history[-1] == C else 0
@@ -100,11 +99,13 @@ def compute_features(player: Player, opponent: Player) -> List[int]:
         total_opponent_d,
         total_player_c,
         total_player_d,
-        len(player.history)
+        len(player.history),
     ]
 
 
-def activate(bias: List[float], hidden: List[float], output: List[float], inputs: List[int]) -> float:
+def activate(
+    bias: List[float], hidden: List[float], output: List[float], inputs: List[int]
+) -> float:
     """
     Compute the output of the neural network:
         output = relu(inputs * hidden_weights + bias) * output_weights
@@ -116,7 +117,9 @@ def activate(bias: List[float], hidden: List[float], output: List[float], inputs
     return output_value
 
 
-def split_weights(weights: List[float], num_features: int, num_hidden: int) -> Tuple[List[List[float]], List[float], List[float]]:
+def split_weights(
+    weights: List[float], num_features: int, num_hidden: int
+) -> Tuple[List[List[float]], List[float], List[float]]:
     """Splits the input vector into the the NN bias weights and layer
     parameters."""
     # Check weights is the right length
@@ -129,12 +132,12 @@ def split_weights(weights: List[float], num_features: int, num_hidden: int) -> T
 
     input2hidden = []
     for i in range(0, number_of_input_to_hidden_weights, num_features):
-        input2hidden.append(weights[i:i + num_features])
+        input2hidden.append(weights[i : i + num_features])
 
     start = number_of_input_to_hidden_weights
     end = number_of_input_to_hidden_weights + number_of_hidden_to_output_weights
 
-    hidden2output = weights[start: end]
+    hidden2output = weights[start:end]
     bias = weights[end:]
     return (input2hidden, hidden2output, bias)
 
@@ -169,19 +172,21 @@ class ANN(Player):
 
     - Artificial Neural Network based strategy: Original name by Martin Jones
     """
-    name = 'ANN'
+
+    name = "ANN"
     classifier = {
-        'memory_depth': float('inf'),
-        'stochastic': False,
-        'inspects_source': False,
-        'makes_use_of': set(),
-        'manipulates_source': False,
-        'manipulates_state': False,
-        'long_run_time': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "inspects_source": False,
+        "makes_use_of": set(),
+        "manipulates_source": False,
+        "manipulates_state": False,
+        "long_run_time": False,
     }
 
-    def __init__(self, weights: List[float], num_features: int,
-                 num_hidden: int) -> None:
+    def __init__(
+        self, weights: List[float], num_features: int, num_hidden: int
+    ) -> None:
         super().__init__()
         (i2h, h2o, bias) = split_weights(weights, num_features, num_hidden)
         self.input_to_hidden_layer_weights = np.matrix(i2h)
@@ -190,10 +195,12 @@ class ANN(Player):
 
     def strategy(self, opponent: Player) -> Action:
         features = compute_features(self, opponent)
-        output = activate(self.bias_weights,
-                          self.input_to_hidden_layer_weights,
-                          self.hidden_to_output_layer_weights,
-                          features)
+        output = activate(
+            self.bias_weights,
+            self.input_to_hidden_layer_weights,
+            self.hidden_to_output_layer_weights,
+            features,
+        )
         if output > 0:
             return C
         else:
@@ -205,6 +212,9 @@ class EvolvedANN(ANN):
     A strategy based on a pre-trained neural network with 17 features and a
     hidden layer of size 10.
 
+    Trained using the `axelrod_dojo` version: 0.0.8
+    Training data is archived at doi.org/10.5281/zenodo.1306926
+
     Names:
 
      - Evolved ANN: Original name by Martin Jones.
@@ -222,6 +232,9 @@ class EvolvedANN5(ANN):
     A strategy based on a pre-trained neural network with 17 features and a
     hidden layer of size 5.
 
+    Trained using the `axelrod_dojo` version: 0.0.8
+    Training data is archived at doi.org/10.5281/zenodo.1306931
+
     Names:
 
      - Evolved ANN 5: Original name by Marc Harper.
@@ -237,11 +250,14 @@ class EvolvedANN5(ANN):
 class EvolvedANNNoise05(ANN):
     """
     A strategy based on a pre-trained neural network with a hidden layer of
-    size 10, trained with noise=0.05.
+    size 5, trained with noise=0.05.
+
+    Trained using the `axelrod_dojo` version: 0.0.8
+    Training data i archived at doi.org/10.5281/zenodo.1314247.
 
     Names:
 
-     - Evolved ANN Noise 05: Original name by Marc Harper.
+     - Evolved ANN Noise 5: Original name by Marc Harper.
     """
 
     name = "Evolved ANN 5 Noise 05"
