@@ -15,15 +15,15 @@ class Appeaser(Player):
     - Appeaser: Original Name by Jochen Müller
     """
 
-    name = 'Appeaser'
+    name = "Appeaser"
     classifier = {
-        'memory_depth': float('inf'),  # Depends on internal memory.
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Depends on internal memory.
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def strategy(self, opponent: Player) -> Action:
