@@ -1,7 +1,8 @@
+from axelrod._strategy_utils import detect_cycle
 from axelrod.action import Action
 from axelrod.player import Player
+
 from .axelrod_first import Joss
-from axelrod._strategy_utils import detect_cycle
 
 C, D = Action.C, Action.D
 
@@ -19,13 +20,13 @@ class Calculator(Player):
 
     name = "Calculator"
     classifier = {
-        'memory_depth': float('inf'),
-        'stochastic': True,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": True,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
