@@ -22,20 +22,29 @@ class SimpleFSM(object):
 
         """
         self._state = initial_state
-        self._state_transitions = {(current_state, input_action): (next_state, output_action) for
-                                   current_state, input_action, next_state, output_action in transitions}  # type: dict
+        self._state_transitions = {
+            (current_state, input_action): (next_state, output_action)
+            for current_state, input_action, next_state, output_action in transitions
+        }  # type: dict
 
         self._raise_error_for_bad_input()
 
     def _raise_error_for_bad_input(self):
-        callable_states = set(pair[0] for pair in self._state_transitions.values())
+        callable_states = set(
+            pair[0] for pair in self._state_transitions.values()
+        )
         callable_states.add(self._state)
         for state in callable_states:
             self._raise_error_for_bad_state(state)
 
     def _raise_error_for_bad_state(self, state: int):
-        if (state, C) not in self._state_transitions or (state, D) not in self._state_transitions:
-            raise ValueError('state: {} does not have values for both C and D'.format(state))
+        if (state, C) not in self._state_transitions or (
+            state,
+            D,
+        ) not in self._state_transitions:
+            raise ValueError(
+                "state: {} does not have values for both C and D".format(state)
+            )
 
     @property
     def state(self) -> int:
@@ -52,7 +61,9 @@ class SimpleFSM(object):
 
     def move(self, opponent_action: Action) -> Action:
         """Computes the response move and changes state."""
-        next_state, next_action = self._state_transitions[(self._state, opponent_action)]
+        next_state, next_action = self._state_transitions[
+            (self._state, opponent_action)
+        ]
         self._state = next_state
         return next_action
 
@@ -60,7 +71,10 @@ class SimpleFSM(object):
         """Equality of two FSMs"""
         if not isinstance(other, SimpleFSM):
             return False
-        return (self._state, self._state_transitions) == (other.state, other.state_transitions)
+        return (self._state, self._state_transitions) == (
+            other.state,
+            other.state_transitions,
+        )
 
 
 class FSMPlayer(Player):
@@ -69,18 +83,21 @@ class FSMPlayer(Player):
     name = "FSM Player"
 
     classifier = {
-        'memory_depth': 1,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": 1,
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
-    def __init__(self, transitions: tuple = ((1, C, 1, C), (1, D, 1, D)),
-                 initial_state: int = 1,
-                 initial_action: Action = C) -> None:
+    def __init__(
+        self,
+        transitions: tuple = ((1, C, 1, C), (1, D, 1, D)),
+        initial_state: int = 1,
+        initial_action: Action = C,
+    ) -> None:
 
         super().__init__()
         self.initial_state = initial_state
@@ -107,15 +124,15 @@ class Fortress3(FSMPlayer):
     - Fortress 3: [Ashlock2006b]_
     """
 
-    name = 'Fortress3'
+    name = "Fortress3"
     classifier = {
-        'memory_depth': 3,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": 2,
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -125,10 +142,12 @@ class Fortress3(FSMPlayer):
             (2, C, 1, D),
             (2, D, 3, C),
             (3, C, 3, C),
-            (3, D, 1, D)
+            (3, D, 1, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class Fortress4(FSMPlayer):
@@ -144,15 +163,15 @@ class Fortress4(FSMPlayer):
     - Fortress 4: [Ashlock2006b]_
     """
 
-    name = 'Fortress4'
+    name = "Fortress4"
     classifier = {
-        'memory_depth': 4,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": 3,
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -164,10 +183,12 @@ class Fortress4(FSMPlayer):
             (3, C, 1, D),
             (3, D, 4, C),
             (4, C, 4, C),
-            (4, D, 1, D)
+            (4, D, 1, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class Predator(FSMPlayer):
@@ -180,15 +201,15 @@ class Predator(FSMPlayer):
     - Predator: [Ashlock2006b]_
     """
 
-    name = 'Predator'
+    name = "Predator"
     classifier = {
-        'memory_depth': 9,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -210,10 +231,12 @@ class Predator(FSMPlayer):
             (7, C, 8, D),
             (7, D, 7, D),
             (8, C, 8, D),
-            (8, D, 6, D)
+            (8, D, 6, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class Pun1(FSMPlayer):
@@ -224,26 +247,23 @@ class Pun1(FSMPlayer):
     - Pun1: [Ashlock2006]_
     """
 
-    name = 'Pun1'
+    name = "Pun1"
     classifier = {
-        'memory_depth': 2,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
-        transitions = (
-            (1, C, 2, C),
-            (1, D, 2, C),
-            (2, C, 1, C),
-            (2, D, 1, D)
-        )
+        transitions = ((1, C, 2, C), (1, D, 2, C), (2, C, 1, C), (2, D, 1, D))
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class Raider(FSMPlayer):
@@ -256,15 +276,15 @@ class Raider(FSMPlayer):
     - Raider: [Ashlock2014]_
     """
 
-    name = 'Raider'
+    name = "Raider"
     classifier = {
-        'memory_depth': 3,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -276,10 +296,12 @@ class Raider(FSMPlayer):
             (2, C, 0, D),
             (2, D, 3, C),
             (3, C, 0, D),
-            (3, D, 1, C)
+            (3, D, 1, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=D
+        )
 
 
 class Ripoff(FSMPlayer):
@@ -291,15 +313,15 @@ class Ripoff(FSMPlayer):
     - Ripoff: [Ashlock2008]_
     """
 
-    name = 'Ripoff'
+    name = "Ripoff"
     classifier = {
-        'memory_depth': 2,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": 3,
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -309,10 +331,68 @@ class Ripoff(FSMPlayer):
             (2, C, 1, D),
             (2, D, 3, C),
             (3, C, 3, C),  # Note that it's TFT in state 3
-            (3, D, 3, D)
+            (3, D, 3, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
+
+
+class UsuallyCooperates(FSMPlayer):
+    """
+    This strategy cooperates except after a C following a D.
+
+    Names:
+
+    - Usually Cooperates (UC): [Ashlock2009]_
+    """
+
+    name = "UsuallyCooperates"
+    classifier = {
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
+    }
+
+    def __init__(self) -> None:
+        transitions = ((1, C, 1, C), (1, D, 2, C), (2, C, 1, D), (2, D, 1, C))
+
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=C
+        )
+
+
+class UsuallyDefects(FSMPlayer):
+    """
+    This strategy defects except after a D following a C.
+
+    Names:
+
+    - Usually Defects (UD): [Ashlock2009]_
+    """
+
+    name = "UsuallyDefects"
+    classifier = {
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
+    }
+
+    def __init__(self) -> None:
+        transitions = ((1, C, 2, D), (1, D, 1, D), (2, C, 1, D), (2, D, 1, C))
+
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class SolutionB1(FSMPlayer):
@@ -324,15 +404,15 @@ class SolutionB1(FSMPlayer):
     - Solution B1: [Ashlock2015]_
     """
 
-    name = 'SolutionB1'
+    name = "SolutionB1"
     classifier = {
-        'memory_depth': 3,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": 2,
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -342,10 +422,12 @@ class SolutionB1(FSMPlayer):
             (2, C, 2, C),
             (2, D, 3, C),
             (3, C, 3, C),
-            (3, D, 3, C)
+            (3, D, 3, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class SolutionB5(FSMPlayer):
@@ -358,15 +440,15 @@ class SolutionB5(FSMPlayer):
     - Solution B5: [Ashlock2015]_
     """
 
-    name = 'SolutionB5'
+    name = "SolutionB5"
     classifier = {
-        'memory_depth': 5,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -382,10 +464,12 @@ class SolutionB5(FSMPlayer):
             (5, C, 5, D),
             (5, D, 4, D),
             (6, C, 3, C),
-            (6, D, 5, D)
+            (6, D, 5, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=D)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=D
+        )
 
 
 class Thumper(FSMPlayer):
@@ -397,26 +481,23 @@ class Thumper(FSMPlayer):
     - Thumper: [Ashlock2008]_
     """
 
-    name = 'Thumper'
+    name = "Thumper"
     classifier = {
-        'memory_depth': 2,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
-        transitions = (
-            (1, C, 1, C),
-            (1, D, 2, D),
-            (2, C, 1, D),
-            (2, D, 1, D)
-        )
+        transitions = ((1, C, 1, C), (1, D, 2, D), (2, C, 1, D), (2, D, 1, D))
 
-        super().__init__(transitions=transitions, initial_state=1, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=1, initial_action=C
+        )
 
 
 class EvolvedFSM4(FSMPlayer):
@@ -430,13 +511,13 @@ class EvolvedFSM4(FSMPlayer):
 
     name = "Evolved FSM 4"
     classifier = {
-        'memory_depth': 4,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -448,10 +529,12 @@ class EvolvedFSM4(FSMPlayer):
             (2, C, 2, D),
             (2, D, 1, C),
             (3, C, 3, D),
-            (3, D, 1, D)
+            (3, D, 1, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class EvolvedFSM16(FSMPlayer):
@@ -466,13 +549,13 @@ class EvolvedFSM16(FSMPlayer):
 
     name = "Evolved FSM 16"
     classifier = {
-        'memory_depth': 16,  # At most
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -485,7 +568,6 @@ class EvolvedFSM16(FSMPlayer):
             (2, D, 14, D),
             (3, C, 3, D),
             (3, D, 3, D),
-
             (5, C, 12, D),
             (5, D, 10, D),
             (6, C, 5, C),
@@ -494,7 +576,6 @@ class EvolvedFSM16(FSMPlayer):
             (7, D, 1, C),
             (8, C, 5, C),
             (8, D, 5, C),
-
             (10, C, 11, D),
             (10, D, 8, C),
             (11, C, 15, D),
@@ -506,10 +587,12 @@ class EvolvedFSM16(FSMPlayer):
             (14, C, 13, D),
             (14, D, 13, D),
             (15, C, 15, D),
-            (15, D, 2, C)
+            (15, D, 2, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class EvolvedFSM16Noise05(FSMPlayer):
@@ -524,13 +607,13 @@ class EvolvedFSM16Noise05(FSMPlayer):
 
     name = "Evolved FSM 16 Noise 05"
     classifier = {
-        'memory_depth': 16,  # At most
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
@@ -549,10 +632,8 @@ class EvolvedFSM16Noise05(FSMPlayer):
             (5, D, 10, D),
             (6, C, 8, C),
             (6, D, 6, D),
-
             (8, C, 2, C),
             (8, D, 4, D),
-
             (10, C, 4, D),
             (10, D, 1, D),
             (11, C, 14, D),
@@ -564,10 +645,12 @@ class EvolvedFSM16Noise05(FSMPlayer):
             (14, C, 3, D),
             (14, D, 13, D),
             (15, C, 5, D),
-            (15, D, 11, C)
+            (15, D, 11, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 # Strategies trained with Moran process objectives
@@ -584,37 +667,54 @@ class TF1(FSMPlayer):
 
     name = "TF1"
     classifier = {
-        'memory_depth': float('inf'),
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
         transitions = (
-            (0, C, 7, C), (0, D, 1, C),
-            (1, C, 11, D), (1, D, 11, D),
-            (2, C, 8, D), (2, D, 8, C),
-            (3, C, 3, C), (3, D, 12, D),
-            (4, C, 6, C), (4, D, 3, C),
-            (5, C, 11, C), (5, D, 8, D),
-            (6, C, 13, D), (6, D, 14, C),
-            (7, C, 4, D), (7, D, 2, D),
-            (8, C, 14, D), (8, D, 8, D),
-            (9, C, 0, C), (9, D, 10, D),
-            (10, C, 8, C), (10, D, 15, C),
-            (11, C, 6, D), (11, D, 5, D),
-            (12, C, 6, D), (12, D, 9, D),
-            (13, C, 9, D), (13, D, 8, D),
-            (14, C, 8, D), (14, D, 13, D),
-            (15, C, 4, C), (15, D, 5, C)
+            (0, C, 7, C),
+            (0, D, 1, C),
+            (1, C, 11, D),
+            (1, D, 11, D),
+            (2, C, 8, D),
+            (2, D, 8, C),
+            (3, C, 3, C),
+            (3, D, 12, D),
+            (4, C, 6, C),
+            (4, D, 3, C),
+            (5, C, 11, C),
+            (5, D, 8, D),
+            (6, C, 13, D),
+            (6, D, 14, C),
+            (7, C, 4, D),
+            (7, D, 2, D),
+            (8, C, 14, D),
+            (8, D, 8, D),
+            (9, C, 0, C),
+            (9, D, 10, D),
+            (10, C, 8, C),
+            (10, D, 15, C),
+            (11, C, 6, D),
+            (11, D, 5, D),
+            (12, C, 6, D),
+            (12, D, 9, D),
+            (13, C, 9, D),
+            (13, D, 8, D),
+            (14, C, 8, D),
+            (14, D, 13, D),
+            (15, C, 4, C),
+            (15, D, 5, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0,
-                         initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class TF2(FSMPlayer):
@@ -628,35 +728,50 @@ class TF2(FSMPlayer):
 
     name = "TF2"
     classifier = {
-        'memory_depth': float('inf'),
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
         transitions = (
-            (0, C, 13, D), (0, D, 12, D),
-            (1, C, 3, D), (1, D, 4, D),
-            (2, C, 14, D), (2, D, 9, D),
-            (3, C, 0, C), (3, D, 1, D),
-            (4, C, 1, D), (4, D, 2, D),
-            (7, C, 12, D), (7, D, 2, D),
-            (8, C, 7, D), (8, D, 9, D),
-            (9, C, 8, D), (9, D, 0, D),
-            (10, C, 2, C), (10, D, 15, C),
-            (11, C, 7, D), (11, D, 13, D),
-            (12, C, 3, C), (12, D, 8, D),
-            (13, C, 7, C), (13, D, 10, D),
-            (14, C, 10, D), (14, D, 7, D),
-            (15, C, 15, C), (15, D, 11, D)
+            (0, C, 13, D),
+            (0, D, 12, D),
+            (1, C, 3, D),
+            (1, D, 4, D),
+            (2, C, 14, D),
+            (2, D, 9, D),
+            (3, C, 0, C),
+            (3, D, 1, D),
+            (4, C, 1, D),
+            (4, D, 2, D),
+            (7, C, 12, D),
+            (7, D, 2, D),
+            (8, C, 7, D),
+            (8, D, 9, D),
+            (9, C, 8, D),
+            (9, D, 0, D),
+            (10, C, 2, C),
+            (10, D, 15, C),
+            (11, C, 7, D),
+            (11, D, 13, D),
+            (12, C, 3, C),
+            (12, D, 8, D),
+            (13, C, 7, C),
+            (13, D, 10, D),
+            (14, C, 10, D),
+            (14, D, 7, D),
+            (15, C, 15, C),
+            (15, D, 11, D),
         )
 
-        super().__init__(transitions=transitions, initial_state=0,
-                         initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class TF3(FSMPlayer):
@@ -670,26 +785,35 @@ class TF3(FSMPlayer):
 
     name = "TF3"
     classifier = {
-        'memory_depth': float('inf'),
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self) -> None:
         transitions = (
-            (0, C, 0, C), (0, D, 3, C),
-            (1, C, 5, D), (1, D, 0, C),
-            (2, C, 3, C), (2, D, 2, D),
-            (3, C, 4, D), (3, D, 6, D),
-            (4, C, 3, C), (4, D, 1, D),
-            (5, C, 6, C), (5, D, 3, D),
-            (6, C, 6, D), (6, D, 6, D),
-            (7, C, 7, D), (7, D, 5, C)
+            (0, C, 0, C),
+            (0, D, 3, C),
+            (1, C, 5, D),
+            (1, D, 0, C),
+            (2, C, 3, C),
+            (2, D, 2, D),
+            (3, C, 4, D),
+            (3, D, 6, D),
+            (4, C, 3, C),
+            (4, D, 1, D),
+            (5, C, 6, C),
+            (5, D, 3, D),
+            (6, C, 6, D),
+            (6, D, 6, D),
+            (7, C, 7, D),
+            (7, D, 5, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0,
-                         initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
