@@ -20,15 +20,15 @@ class GradualKiller(Player):
     """
 
     # These are various properties for the strategy
-    name = 'Gradual Killer'
+    name = "Gradual Killer"
     classifier = {
-        'memory_depth': float('Inf'),
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("Inf"),
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def strategy(self, opponent: Player) -> Action:
