@@ -1,15 +1,21 @@
-from numpy.random import choice
 import random
 
-from axelrod.strategies import TitForTat
 from axelrod.action import Action
 from axelrod.player import Player, obey_axelrod
+from axelrod.strategies import TitForTat
 from axelrod.strategy_transformers import NiceTransformer
+from numpy.random import choice
+
 from ._strategies import all_strategies
 from .hunter import (
-    AlternatorHunter, CooperatorHunter, CycleHunter, DefectorHunter,
-    EventualCycleHunter, MathConstantHunter, RandomHunter,)
-
+    AlternatorHunter,
+    CooperatorHunter,
+    CycleHunter,
+    DefectorHunter,
+    EventualCycleHunter,
+    MathConstantHunter,
+    RandomHunter,
+)
 
 # Needs to be computed manually to prevent circular dependency
 ordinary_strategies = [s for s in all_strategies if obey_axelrod(s)]
@@ -27,13 +33,13 @@ class MetaPlayer(Player):
 
     name = "Meta Player"
     classifier = {
-        'memory_depth': float('inf'),  # Long memory
-        'stochastic': True,
-        'makes_use_of': {'game', 'length'},
-        'long_run_time': True,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Long memory
+        "stochastic": True,
+        "makes_use_of": {"game", "length"},
+        "long_run_time": True,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self, team=None):
@@ -56,18 +62,22 @@ class MetaPlayer(Player):
 
         # This player inherits the classifiers of its team.
         # Note that memory_depth is not simply the max memory_depth of the team.
-        for key in ['stochastic',
-                    'inspects_source',
-                    'manipulates_source',
-                    'manipulates_state']:
+        for key in [
+            "stochastic",
+            "inspects_source",
+            "manipulates_source",
+            "manipulates_state",
+        ]:
             self.classifier[key] = any(t.classifier[key] for t in self.team)
 
         for t in self.team:
-            self.classifier['makes_use_of'].update(t.classifier['makes_use_of'])
+            self.classifier["makes_use_of"].update(t.classifier["makes_use_of"])
 
     def __repr__(self):
         team_size = len(self.team)
-        return '{}: {} player{}'.format(self.name, team_size, 's' if team_size > 1 else '')
+        return "{}: {} player{}".format(
+            self.name, team_size, "s" if team_size > 1 else ""
+        )
 
     def strategy(self, opponent):
         # Get the results of all our players.
@@ -142,7 +152,7 @@ class MetaWinner(MetaPlayer):
         # For each player, we will keep the history of proposed moves and
         # a running score since the beginning of the game.
         self.scores = [0] * len(self.team)
-        self.classifier['long_run_time'] = True
+        self.classifier["long_run_time"] = True
 
     def _update_scores(self, opponent):
         # Update the running score for each player, before determining the
@@ -158,8 +168,9 @@ class MetaWinner(MetaPlayer):
         self._update_scores(opponent)
         # Choice an action based on the collection of scores
         bestscore = max(self.scores)
-        beststrategies = [i for (i, score) in enumerate(self.scores)
-                          if score == bestscore]
+        beststrategies = [
+            i for (i, score) in enumerate(self.scores) if score == bestscore
+        ]
         bestproposals = [results[i] for i in beststrategies]
         bestresult = C if C in bestproposals else D
         return bestresult
@@ -204,13 +215,13 @@ class MetaHunter(MetaPlayer):
 
     name = "Meta Hunter"
     classifier = {
-        'memory_depth': float('inf'),  # Long memory
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Long memory
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self):
@@ -221,8 +232,14 @@ class MetaHunter(MetaPlayer):
         # Random Hunter and Math Constant Hunter, since together they catch
         # strategies that are lightly randomized but still quite constant
         # (the tricky/suspicious ones).
-        team = [DefectorHunter, AlternatorHunter, RandomHunter,
-                MathConstantHunter, CycleHunter, EventualCycleHunter]
+        team = [
+            DefectorHunter,
+            AlternatorHunter,
+            RandomHunter,
+            MathConstantHunter,
+            CycleHunter,
+            EventualCycleHunter,
+        ]
 
         super().__init__(team=team)
 
@@ -252,21 +269,27 @@ class MetaHunterAggressive(MetaPlayer):
 
     name = "Meta Hunter Aggressive"
     classifier = {
-        'memory_depth': float('inf'),  # Long memory
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Long memory
+        "stochastic": False,
+        "makes_use_of": set(),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self, team=None):
         # This version uses CooperatorHunter
         if team is None:
-            team = [DefectorHunter, AlternatorHunter, RandomHunter,
-                    MathConstantHunter, CycleHunter, EventualCycleHunter,
-                    CooperatorHunter]
+            team = [
+                DefectorHunter,
+                AlternatorHunter,
+                RandomHunter,
+                MathConstantHunter,
+                CycleHunter,
+                EventualCycleHunter,
+                CooperatorHunter,
+            ]
 
         super().__init__(team=team)
 
@@ -297,7 +320,7 @@ class MetaMajorityMemoryOne(MetaMajority):
     name = "Meta Majority Memory One"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth'] <= 1]
+        team = [s for s in ordinary_strategies if s().classifier["memory_depth"] <= 1]
         super().__init__(team=team)
         self.classifier["long_run_time"] = False
 
@@ -313,8 +336,11 @@ class MetaMajorityFiniteMemory(MetaMajority):
     name = "Meta Majority Finite Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                < float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] < float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -329,8 +355,11 @@ class MetaMajorityLongMemory(MetaMajority):
     name = "Meta Majority Long Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                == float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] == float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -345,7 +374,7 @@ class MetaWinnerMemoryOne(MetaWinner):
     name = "Meta Winner Memory One"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth'] <= 1]
+        team = [s for s in ordinary_strategies if s().classifier["memory_depth"] <= 1]
         super().__init__(team=team)
         self.classifier["long_run_time"] = False
 
@@ -361,8 +390,11 @@ class MetaWinnerFiniteMemory(MetaWinner):
     name = "Meta Winner Finite Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                < float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] < float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -373,11 +405,15 @@ class MetaWinnerLongMemory(MetaWinner):
 
     - Meta Winner Long Memory: Original name by Marc Harper
     """
+
     name = "Meta Winner Long Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                == float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] == float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -392,10 +428,9 @@ class MetaWinnerDeterministic(MetaWinner):
     name = "Meta Winner Deterministic"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if
-                not s().classifier['stochastic']]
+        team = [s for s in ordinary_strategies if not s().classifier["stochastic"]]
         super().__init__(team=team)
-        self.classifier['stochastic'] = False
+        self.classifier["stochastic"] = False
 
 
 class MetaWinnerStochastic(MetaWinner):
@@ -409,8 +444,7 @@ class MetaWinnerStochastic(MetaWinner):
     name = "Meta Winner Stochastic"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if
-                s().classifier['stochastic']]
+        team = [s for s in ordinary_strategies if s().classifier["stochastic"]]
         super().__init__(team=team)
 
 
@@ -437,13 +471,13 @@ class MetaMixer(MetaPlayer):
 
     name = "Meta Mixer"
     classifier = {
-        'memory_depth': float('inf'),  # Long memory
-        'stochastic': True,
-        'makes_use_of': set(),
-        'long_run_time': True,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Long memory
+        "stochastic": True,
+        "makes_use_of": set(),
+        "long_run_time": True,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
     def __init__(self, team=None, distribution=None):
@@ -466,8 +500,7 @@ class NMWEDeterministic(NiceMetaWinnerEnsemble):
     name = "NMWE Deterministic"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if
-                not s().classifier['stochastic']]
+        team = [s for s in ordinary_strategies if not s().classifier["stochastic"]]
         super().__init__(team=team)
         self.classifier["stochastic"] = True
 
@@ -483,8 +516,7 @@ class NMWEStochastic(NiceMetaWinnerEnsemble):
     name = "NMWE Stochastic"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if
-                s().classifier['stochastic']]
+        team = [s for s in ordinary_strategies if s().classifier["stochastic"]]
         super().__init__(team=team)
 
 
@@ -499,8 +531,11 @@ class NMWEFiniteMemory(NiceMetaWinnerEnsemble):
     name = "NMWE Finite Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                < float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] < float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -515,8 +550,11 @@ class NMWELongMemory(NiceMetaWinnerEnsemble):
     name = "NMWE Long Memory"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                == float('inf')]
+        team = [
+            s
+            for s in ordinary_strategies
+            if s().classifier["memory_depth"] == float("inf")
+        ]
         super().__init__(team=team)
 
 
@@ -531,11 +569,11 @@ class NMWEMemoryOne(NiceMetaWinnerEnsemble):
     name = "NMWE Memory One"
 
     def __init__(self):
-        team = [s for s in ordinary_strategies if s().classifier['memory_depth']
-                <= 1]
+        team = [s for s in ordinary_strategies if s().classifier["memory_depth"] <= 1]
         super().__init__(team=team)
         self.classifier["long_run_time"] = False
 
+
 class MemoryDecay(MetaPlayer):
     """
     A player utilizes the (default) Tit for Tat strategy for the first (default) 15 turns,
@@ -554,22 +592,29 @@ class MemoryDecay(MetaPlayer):
 
     Name: Memory Decay
     """
-    name = 'Memory Decay'
+
+    name = "Memory Decay"
     classifier = {
-        'memory_depth' : float('inf'),
-        'long_run_time' : False,
-        'stochastic' : True,
-        'makes_use_of' : set(),
-        'inspects_source' : False,
-        'manipulates_source' : False,
-        'manipulates_state' : False
+        "memory_depth": float("inf"),
+        "long_run_time": False,
+        "stochastic": True,
+        "makes_use_of": set(),
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
 
-    def __init__(self, p_memory_delete: float = 0.1, p_memory_alter: float = 0.03,
-                 loss_value: float = -2, gain_value: float = 1,
-                 memory: list = None, start_strategy: Player = TitForTat,
-                 start_strategy_duration: int = 15):
-        super().__init__(team = [start_strategy])
+    def __init__(
+        self,
+        p_memory_delete: float = 0.1,
+        p_memory_alter: float = 0.03,
+        loss_value: float = -2,
+        gain_value: float = 1,
+        memory: list = None,
+        start_strategy: Player = TitForTat,
+        start_strategy_duration: int = 15,
+    ):
+        super().__init__(team=[start_strategy])
         self.classifier["stochastic"] = True
         self.p_memory_delete = p_memory_delete
         self.p_memory_alter = p_memory_alter
@@ -586,10 +631,7 @@ class MemoryDecay(MetaPlayer):
         Translates the actions (D and C) to numeric values (loss_value and
         gain_value).
         """
-        values = {
-            C: self.gain_value,
-            D: self.loss_value
-        }
+        values = {C: self.gain_value, D: self.loss_value}
         self.gloss_values = [values[action] for action in self.memory]
 
     def memory_alter(self):
