@@ -1,12 +1,11 @@
-from collections import OrderedDict
 import random
+from collections import OrderedDict
+from typing import Dict, List, Union
 
 from axelrod.action import Action, actions_to_str
 from axelrod.player import Player
 from axelrod.random_ import random_choice
 
-from typing import List, Dict, Union
-
 Score = Union[int, float]
 
 C, D = Action.C, Action.D
@@ -24,15 +23,15 @@ class RiskyQLearner(Player):
     - Risky Q Learner: Original name by Geraint Palmer
     """
 
-    name = 'Risky QLearner'
+    name = "Risky QLearner"
     classifier = {
-        'memory_depth': float('inf'),  # Long memory
-        'stochastic': True,
-        'makes_use_of': set(["game"]),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
+        "memory_depth": float("inf"),  # Long memory
+        "stochastic": True,
+        "makes_use_of": set(["game"]),
+        "long_run_time": False,
+        "inspects_source": False,
+        "manipulates_source": False,
+        "manipulates_state": False,
     }
     learning_rate = 0.9
     discount_rate = 0.9
@@ -46,15 +45,15 @@ class RiskyQLearner(Player):
 
         # Set this explicitely, since the constructor of super will not pick it up
         # for any subclasses that do not override methods using random calls.
-        self.classifier['stochastic'] = True
+        self.classifier["stochastic"] = True
 
-        self.prev_action = None # type: Action
-        self.original_prev_action = None # type: Action
-        self.history = [] # type: List[Action]
+        self.prev_action = None  # type: Action
+        self.original_prev_action = None  # type: Action
+        self.history = []  # type: List[Action]
         self.score = 0
-        self.Qs = OrderedDict({'':  OrderedDict(zip([C, D], [0, 0]))})
-        self.Vs = OrderedDict({'': 0})
-        self.prev_state = ''
+        self.Qs = OrderedDict({"": OrderedDict(zip([C, D], [0, 0]))})
+        self.Vs = OrderedDict({"": 0})
+        self.prev_state = ""
 
     def receive_match_attributes(self):
         (R, P, S, T) = self.match_attributes["game"].RPST()
@@ -81,7 +80,7 @@ class RiskyQLearner(Player):
         Selects the action based on the epsilon-soft policy
         """
         rnd_num = random.random()
-        p = 1. - self.action_selection_parameter
+        p = 1.0 - self.action_selection_parameter
         if rnd_num < p:
             return max(self.Qs[state], key=lambda x: self.Qs[state][x])
         return random_choice()
@@ -91,16 +90,17 @@ class RiskyQLearner(Player):
         Finds the my_state (the opponents last n moves +
         its previous proportion of playing C) as a hashable state
         """
-        prob = '{:.1f}'.format(opponent.cooperations)
-        action_str = actions_to_str(
-            opponent.history[-self.memory_length:])
+        prob = "{:.1f}".format(opponent.cooperations)
+        action_str = actions_to_str(opponent.history[-self.memory_length :])
         return action_str + prob
 
     def perform_q_learning(self, prev_state: str, state: str, action: Action, reward):
         """
         Performs the qlearning algorithm
         """
-        self.Qs[prev_state][action] = (1.-self.learning_rate)*self.Qs[prev_state][action] + self.learning_rate*(reward + self.discount_rate*self.Vs[state])
+        self.Qs[prev_state][action] = (1.0 - self.learning_rate) * self.Qs[prev_state][
+            action
+        ] + self.learning_rate * (reward + self.discount_rate * self.Vs[state])
         self.Vs[prev_state] = max(self.Qs[prev_state].values())
 
     def find_reward(self, opponent: Player) -> Dict[Action, Dict[Action, Score]]:
@@ -115,7 +115,6 @@ class RiskyQLearner(Player):
         return self.payoff_matrix[self.prev_action][opp_prev_action]
 
 
-
 class ArrogantQLearner(RiskyQLearner):
     """A player who learns the best strategies through the q-learning
     algorithm.
@@ -127,7 +126,7 @@ class ArrogantQLearner(RiskyQLearner):
     - Arrogant Q Learner: Original name by Geraint Palmer
     """
 
-    name = 'Arrogant QLearner'
+    name = "Arrogant QLearner"
     learning_rate = 0.9
     discount_rate = 0.1
 
@@ -142,7 +141,7 @@ class HesitantQLearner(RiskyQLearner):
     - Hesitant Q Learner: Original name by Geraint Palmer
     """
 
-    name = 'Hesitant QLearner'
+    name = "Hesitant QLearner"
     learning_rate = 0.1
     discount_rate = 0.9
 
@@ -158,6 +157,6 @@ class CautiousQLearner(RiskyQLearner):
     - Cautious Q Learner: Original name by Geraint Palmer
     """
 
-    name = 'Cautious QLearner'
+    name = "Cautious QLearner"
     learning_rate = 0.1
     discount_rate = 0.1
